"""Top-level package for phylum-ci."""

__author__ = """Phylum, Inc."""
__email__ = "engineering@phylum.io"
# TODO: bump this version to at least 0.1.0 once there is *any* amount of
#       functionality provided by this package. Right now, this is just a
#       placeholder to be able to "reserve" the package name on PyPI.
__version__ = "0.0.1"
